.. _spkg_ipython_genutils:

ipython_genutils: Vestigial utilities from IPython
==================================================

Description
-----------

Vestigial utilities from IPython


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    0.2.0

version_requirements.txt::

    ipython_genutils >=0.2.0

Equivalent System Packages
--------------------------

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install ipython_genutils

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-ipython_genutils

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/ipython_genutils

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install py-ipython_genutils

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-ipython_genutils

# See https://repology.org/project/python:ipython-genutils/versions

If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then ``./configure`` will check if the system package can be used.
